;; blue-heart/theme.jl
;; $Id$

;; Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>

;; This file is part of sawmill.

;; sawmill is free software; you can redistribute it and/or modify it
;; under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; sawmill is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with sawmill; see the file COPYING.  If not, write to
;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.


;; image loading

;; 16x16
(defvar blue-heart:bottom-left-i (list (make-image "A_b_corner_bl1.png")
				       (make-image "A_b_corner_H_bl1.png")))

(defvar blue-heart:bottom-right-i (list (make-image "A_b_corner_br1.png")
					(make-image "A_b_corner_H_br1.png")))

;; 225x15
(defvar blue-heart:title-i
  (list (set-image-border (make-image "A_b_title1.png") 4 4 4 4)
	(set-image-border (make-image "A_b_title3.png") 4 4 4 4)))

;; 5x56
(defvar blue-heart:vbar-i (set-image-border (make-image "vlbar.png") 2 2 2 2))

;; 57x5
(defvar blue-heart:hbar-i (set-image-border (make-image "hbar.png") 2 2 2 2))

;; 16x16
(defvar blue-heart:menu-i (list (make-image "button_iconify_1.png")
				(make-image "b_iconify_1.png")
				(make-image "button_iconify_2.png")
				(make-image "button_iconify_3.png")))

;; 16x16
(defvar blue-heart:close-i (list (make-image "button_kill_1.png")
				 (make-image "b_kill_1.png")
				 (make-image "button_kill_2.png")
				 (make-image "button_kill_3.png")))




;; frame definitions

(defvar blue-heart:frame
  `(;; left button
    ((background . ,blue-heart:menu-i)
     (left-edge . -5)
     (top-edge . -16)
     (class . menu-button))
    ;; title bar
    ((background . ,blue-heart:title-i)
     (foreground . "white")
     (text . window-name)
     (x-justify . center)
     (y-justify . center)
     (left-edge . 11)
     (right-edge . 11)
     (top-edge . -16)
     (class . title))
    ;; right button
    ((background . ,blue-heart:close-i)
     (right-edge . -5)
     (top-edge . -16)
     (class . close-button))
    ;; left frame
    ((background . ,blue-heart:vbar-i)
     (left-edge . -5)
     (top-edge . 0)
     (bottom-edge . 11)
     (class . left-border))
    ;; right frame
    ((background . ,blue-heart:vbar-i)
     (right-edge . -5)
     (top-edge . 0)
     (bottom-edge . 11)
     (class . right-border))
    ;; bottom frame
    ((background . ,blue-heart:hbar-i)
     (left-edge . 11)
     (right-edge . 11)
     (bottom-edge . -5)
     (class . bottom-border))
    ;; bottom-left corner
    ((background . ,blue-heart:bottom-left-i)
     (left-edge . -5)
     (bottom-edge . -5)
     (class . bottom-left-corner))
    ;; bottom-right corner
    ((background . ,blue-heart:bottom-right-i)
     (right-edge . -5)
     (bottom-edge . -5)
     (class . bottom-right-corner))))

(defvar blue-heart:shaped-frame
  `(;; left button
    ((background . ,blue-heart:menu-i)
     (left-edge . -5)
     (top-edge . -16)
     (class . menu-button))
    ;; title bar
    ((background . ,blue-heart:title-i)
     (foreground . "white")
     (text . window-name)
     (x-justify . center)
     (y-justify . center)
     (left-edge . 11)
     (right-edge . 11)
     (top-edge . -16)
     (class . title))
    ;; right button
    ((background . ,blue-heart:close-i)
     (right-edge . -5)
     (top-edge . -16)
     (class . close-button))))

(defvar blue-heart:transient-frame
  `(;; title bar
    ((background . ,blue-heart:title-i)
     (foreground . "white")
     (text . window-name)
     (x-justify . center)
     (y-justify . center)
     (left-edge . -5)
     (right-edge . -5)
     (top-edge . -16)
     (class . title))
    ;; left frame
    ((background . ,blue-heart:vbar-i)
     (left-edge . -5)
     (top-edge . 0)
     (bottom-edge . 11)
     (class . left-border))
    ;; right frame
    ((background . ,blue-heart:vbar-i)
     (right-edge . -5)
     (top-edge . 0)
     (bottom-edge . 11)
     (class . right-border))
    ;; bottom frame
    ((background . ,blue-heart:hbar-i)
     (left-edge . 11)
     (right-edge . 11)
     (bottom-edge . -5)
     (class . bottom-border))
    ;; bottom-left corner
    ((background . ,blue-heart:bottom-left-i)
     (left-edge . -5)
     (bottom-edge . -5)
     (class . bottom-left-corner))
    ;; bottom-right corner
    ((background . ,blue-heart:bottom-right-i)
     (right-edge . -5)
     (bottom-edge . -5)
     (class . bottom-right-corner))))

(defvar blue-heart:shaped-transient-frame
  `(;; title bar
    ((background . ,blue-heart:title-i)
     (foreground . "white")
     (text . window-name)
     (x-justify . center)
     (y-justify . center)
     (left-edge . -5)
     (right-edge . -5)
     (top-edge . -16)
     (class . title))))



;; called to produce a frame definition for window W (of type TYPE)
(defun blue-heart:frame-style (w type)
  (cond ((eq type 'shaped)
	 'blue-heart:shaped-frame)
	((eq type 'transient)
	 'blue-heart:transient-frame)
	((eq type 'shaped-transient)
	 'blue-heart:shaped-transient-frame)
	((eq type 'unframed)
	 'nil-frame)
	(t
	 'blue-heart:frame)))


;;  initialisation

(add-frame-style 'blue-heart 'blue-heart:frame-style)
